@@ -15,9 +15,13 @@ function(explanatory, response, Y_0, level=NA) {
 		Rn[i] <- sqrt(length(ind)) * (fit$threshold_estimate_explanatory - fit_bst$threshold_estimate_explanatory)
 	}
 	qU <- quantile(Rn, level + alpha/2)
-	qL <- quantile(Rn, alpha/2)	
+	qL <- quantile(Rn, alpha/2)
 	uBand <- fit$threshold_estimate_explanatory  + qU / sqrt(n)
 	lBand <- fit$threshold_estimate_explanatory  + qL / sqrt(n)
-
-	return(list(estimate=fit$threshold_estimate_explanatory,lower=max(lBand, min(explanatory)), upper=min(uBand, max(explanatory)), sigmaSq=NA, deriv_d0=NA))
+	if (lBand < uBand) {
+		return(list(estimate=mean(c(max(lBand, min(explanatory)), min(uBand, max(explanatory)))),lower=max(lBand, min(explanatory)), upper=min(uBand, max(explanatory)), sigmaSq=NA, deriv_d0=NA))
+	}
+	else {
+		return(list(estimate=mean(c(max(lBand, min(explanatory)), min(lBand, max(explanatory)))),lower=max(uBand, min(explanatory)), upper=min(lBand, max(explanatory)), sigmaSq=NA, deriv_d0=NA))
+	}
 }
